Emerge.Engine.Reconcile (Emerge v0.2.1)

Copy Markdown View Source

Reconcile Emerge.Engine.Element trees into stable ids and patch operations.

Summary

Functions

Assign ids to a tree without a previous version.

Reconcile a new tree against the previous vdom.

Types

Functions

assign_ids(element)

Assign ids to a tree without a previous version.

reconcile(old_vnode, element)

@spec reconcile(Emerge.Engine.VNode.t() | nil, Emerge.Engine.Element.t()) :: result()

Reconcile a new tree against the previous vdom.