Emerge.Engine.Serialization (Emerge v0.2.1)

Copy Markdown View Source

Binary serialization for Emerge.Engine.Element trees.

Summary

Functions

Decode a binary payload into a tree.

Assign ids and encode a tree into a binary payload.

Encode a tree that already has numeric ids assigned.

Functions

decode(arg1)

@spec decode(binary()) :: Emerge.Engine.Element.t()

Decode a binary payload into a tree.

encode(tree)

Assign ids and encode a tree into a binary payload.

encode_tree(tree)

@spec encode_tree(Emerge.Engine.Element.t()) :: binary()

Encode a tree that already has numeric ids assigned.