Reconcile Emerge.Engine.Element trees into stable ids and patch operations.
Summary
Functions
Assign ids to a tree without a previous version.
Reconcile a new tree against the previous vdom.
Types
@type result() :: {Emerge.Engine.VNode.t(), [Emerge.Engine.Patch.patch()], Emerge.Engine.Element.t()}
Functions
@spec assign_ids(Emerge.Engine.Element.t()) :: {Emerge.Engine.VNode.t(), Emerge.Engine.Element.t()}
Assign ids to a tree without a previous version.
@spec reconcile(Emerge.Engine.VNode.t() | nil, Emerge.Engine.Element.t()) :: result()
Reconcile a new tree against the previous vdom.