Binary serialization for Emerge.Engine.Element trees.
Summary
Functions
Decode a binary payload into a tree.
Assign ids and encode a tree into a binary payload.
Encode a tree that already has numeric ids assigned.
Functions
@spec decode(binary()) :: Emerge.Engine.Element.t()
Decode a binary payload into a tree.
@spec encode(Emerge.Engine.Element.t()) :: {binary(), Emerge.Engine.Element.t()}
Assign ids and encode a tree into a binary payload.
@spec encode_tree(Emerge.Engine.Element.t()) :: binary()
Encode a tree that already has numeric ids assigned.