Runtime GenServer backing use Emerge viewport modules.
This module owns the process lifecycle, renderer integration, tree upload and
patch flow, and event routing used by the public Emerge API.
Most application code should use Emerge directly instead of calling this
module.
Summary
Functions
Returns a specification to start this module under a supervisor.
Types
@type t() :: map()
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
@spec notify_source_reloaded(term()) :: :ok